const Lang = imports.lang;
const St = imports.gi.St;
const Shell = imports.gi.Shell;
const Main = imports.ui.main;
const MessageTray = Main.messageTray;
const LayoutManager = Main.layoutManager;

const Me = imports.misc.extensionUtils.getCurrentExtension();
const Convenience = Me.imports.convenience;

const ChangeMT = new Lang.Class({
    Name: 'ChangeMT',

    _init: function(enabled) {
        this.settingsEnabled = enabled;
        this.dwell = 0;
        this.topButton = new St.Bin({ style_class: 'panel-button',
                                      reactive: true,
                                      can_focus: true,
                                      x_fill: true,
                                      y_fill: false,
                                      track_hover: true });
        let icon = new St.Icon({ icon_name: 'preferences-system-notifications-symbolic',
                                 style_class: 'system-status-icon' });

        this.topButton.set_child(icon);
        this.topButtonSignal = this.topButton.connect('button-release-event', this.showMessageTray);
        if (enabled) {
            this.enable();
        }
    },

    disable: function() {
        if("_trayPressure" in LayoutManager) {
            LayoutManager._trayPressure._keybindingMode = 
                Shell.KeyBindingMode.NORMAL | Shell.KeyBindingMode.OVERVIEW;
        }

        if(this.dwell) {
            MessageTray._trayDwellTimeout = this.dwell;
            messageTrayDwell = 0;
        }

	    Main.panel._rightBox.remove_child(this.topButton);
        this.settingsEnabled = true;
    },

    enable: function() {
        this.dwell = MessageTray._trayDwellTimeout;

        if (this.settingsEnabled) {
            if("_trayPressure" in LayoutManager) {
                LayoutManager._trayPressure._keybindingMode = Shell.KeyBindingMode.OVERVIEW;
            }
            
            MessageTray._trayDwellTimeout = function() { return false; };
        }

	    Main.panel._rightBox.insert_child_at_index(this.topButton, 0);
        this.settingsEnabled = false;
    },

    showMessageTray: function() {
	    if (MessageTray._trayState === 0) {
		    MessageTray.openTray();
	    } else {
		    MessageTray.hide();
	    }
    },

    destroy: function() {
        this.disable();
        
        if(this.dwell) {
            MessageTray._trayDwellTimeout = this.dwell;
            this.dwell = 0;
        }

        if(this.topButtonSignal != null) {
	        this.topButton.disconnect(this.topButtonSignal);
	        this.topButtonSignal = null;
        }
    }
});

